==> threetictac_0.6.2-1.tar.gz: threetictac-0.6.2/src/graphicsscene.cpp <==
/*
    A Qt game based on Tic Tac Toe for Maemo
    Copyright (C) 2010  Victor Blazquez Francisco <victor.blazquez@gmail.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "graphicsscene.h"
#include "shape.h"
#include "machineia.h"
#include "finalline.h"

#include <QGraphicsItem>
#include <QGraphicsSceneMouseEvent>
#include <QPropertyAnimation>
#include <QObject>
#include <QDebug>
#include <QInputDialog>
#include <QMessageBox>
#include <QString>
#include <QPushButton>

GraphicsScene::GraphicsScene(QObject* parent): QGraphicsScene(parent)
{
	QGraphicsPixmapItem* m_background = addPixmap(QPixmap("/usr/share/threeTicTac/bg.png", 0));
	m_background->setZValue(-3);
	m_background->setPos(-350, -180);
	m_background->setData(Shapes , Img);
	
	QGraphicsPixmapItem* m_gridImage = addPixmap(QPixmap("/usr/share/threeTicTac/lines.png", 0));
	m_gridImage->setZValue(-2);
	m_gridImage->setPos(-103,-103);
	m_gridImage->setData(Shapes , Img);

	m_textLevel = new QGraphicsTextItem;
	m_textLevel->setPos(-300,200);
	QFont serifFont("Times", 18, QFont::Bold);
	m_textLevel->setFont(serifFont);
	m_textLevel->setDefaultTextColor(Qt::white);
	m_textLevel->setData(Shapes, "textLevel");
	addItem(m_textLevel);
	updateLevelText();

	m_winner = new QGraphicsTextItem;
	serifFont.setPointSize(24);
	m_winner->setFont(serifFont);
	m_winner->setDefaultTextColor(Qt::white);
	addItem(m_winner);
	
	m_restart = new QGraphicsTextItem;
	m_restart->setPos(250, 180);
	serifFont.setPointSize(24);
	m_restart->setFont(serifFont);
	m_restart->setDefaultTextColor(Qt::green);
	m_restart->setData(Shapes, "restartGame");
	addItem(m_restart);
	
	
	m_grid.resize(All);
	int *p = matrix[0];
	for (int i=0 ; i< All ; ++i, p++) 
	{
		m_grid[i] = new Shape(i);
		m_grid[i]->addData(Shapes, Empty);
		addItem(m_grid[i]);
		*p = Empty;
	}
	fl = new FinalLine;
	block = false;
	endGame = false;
	win = draw = lose = 0;
}

// void GraphicsScene::askUserName()
// {
// 	QInputDialog id;
// 	userName = id.getText(NULL, "User name","What is your name?");
// }

void GraphicsScene::changeLevel()
{	
	m_machine.setLevel(m_machine.level() + 1);
	updateLevelText();
	restartGame();
}

void GraphicsScene::changeLevel(int level)
{
	m_machine.setLevel(level);
	updateLevelText();
	restartGame();
}

void GraphicsScene::updateLevelText()
{
	QString level_string;
	int machine_level = m_machine.level();
	if (machine_level == 0)
		level_string = "Level: I";
	else
		level_string = "Level: II";
	m_textLevel->setPlainText(level_string);
}

void GraphicsScene::mousePressEvent(QGraphicsSceneMouseEvent* event)
{
	QGraphicsScene::mousePressEvent(event);
	QGraphicsItem* item = itemAt(event->scenePos());

	if (!block && !endGame)
	{
		block = true;
		
		if (item->data(Shapes) == Empty) {
			int element = item->data(Positions).toInt();
			
			animOp = new QPropertyAnimation(m_grid[element], "opacity");
			animOp->setStartValue(0);
			animOp->setDuration(400);
			animOp->setEndValue(1);
			animOp->start();	
			m_grid[element]->addData(Shapes,Human);
			matrix[element/3][element%3] = Human;

			connect(animOp, SIGNAL(finished()), this, SLOT(endUserAnimation()));
		}
		else
			block = false;
	}
	
	if (item->data(Shapes) == "textLevel")
		changeLevel();
	if (item->data(Shapes) == "restartGame")
		cleanAll();
}

bool GraphicsScene::algunaCasillaLibre() 
{
	for (int i=0 ; i< All ; ++i)
	{
		if (m_grid[i]->data(Shapes).toInt() == Empty) 
			return true;
	}
	return false;
}

void GraphicsScene::endUserAnimation()
{
    delete animOp;
	if (!checkFinish())
	{
		block = true;
		CPUMove();
	}
}

void GraphicsScene::CPUMove()
{
	m_machine.updateMatrix(matrix);
	int element = m_machine.bestPosition();
	
	animOp = new QPropertyAnimation(m_grid[element], "opacity");
	animOp->setStartValue(0);
	animOp->setDuration(800);
	animOp->setEndValue(1);
	animOp->start();	

	m_grid[element]->addData(Shapes,Machine);
	matrix[element/3][element%3] = Machine;
	connect(animOp, SIGNAL(finished()), this, SLOT(endMachineAnimation()));
}

void GraphicsScene::endMachineAnimation()
{
	delete animOp;
	checkFinish();
	block = false;
}

bool GraphicsScene::checkFinish() 
{		
	// Machine = maquina  // Human = jugador
	int result = -2;
	/*	0	1	2	*/
	/*	3	4	5	*/
	/*	6	7	8	*/
	/********** GANA MAQUINA ********/
	// Filas
	if (matrix[0][0] == Machine && matrix[0][1] == Machine && matrix[0][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-90,-50), QPoint(190,-50));
	}
	if (matrix[1][0] == Machine && matrix[1][1] == Machine && matrix[1][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-90,50), QPoint(190,50));
	}
	if (matrix[2][0] == Machine && matrix[2][1] == Machine && matrix[2][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-90,150), QPoint(190,150));
	}
	// Columnas
	if (matrix[0][0] == Machine && matrix[1][0] == Machine && matrix[2][0] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-50,-90), QPoint(-50, 190));
	}
	if (matrix[0][1] == Machine && matrix[1][1] == Machine && matrix[2][1] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(50,-90), QPoint(50,190));
	}
	if (matrix[0][2] == Machine && matrix[1][2] == Machine && matrix[2][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(150,-90), QPoint(150,190));
	}
	// Diagonal
	if (matrix[0][0] == Machine && matrix[1][1] == Machine && matrix[2][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-75,-75), QPoint(175,175));
	}
	if (matrix[0][2] == Machine && matrix[1][1] == Machine && matrix[2][0] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(175,-75), QPoint(-75,175));
	}

	/********** GANA JUGADOR ********/
	//Columnas
	if (matrix[0][0] == Human && matrix[0][1] == Human && matrix[0][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-90,-50), QPoint(190,-50));
	}
	if (matrix[1][0] == Human && matrix[1][1] == Human && matrix[1][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-90,50), QPoint(190,50));
	}
	if (matrix[2][0] == Human && matrix[2][1] == Human && matrix[2][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-90,150), QPoint(190,150));
	}
	//Filas
	if (matrix[0][0] == Human && matrix[1][0] == Human && matrix[2][0] == Human) {
		result = Human;
		fl->setPoints(QPoint(-50,-90), QPoint(-50, 190));
	}
	if (matrix[0][1] == Human && matrix[1][1] == Human && matrix[2][1] == Human) {
		result = Human;
		fl->setPoints(QPoint(50,-90), QPoint(50,190));
	}
	if (matrix[0][2] == Human && matrix[1][2] == Human && matrix[2][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(150,-90), QPoint(150,190));
	}
	// Diagonal
	if (matrix[0][0] == Human && matrix[1][1] == Human && matrix[2][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-75,-75), QPoint(175,175));
	}
	if (matrix[0][2] == Human && matrix[1][1] == Human && matrix[2][0] == Human) {
		result = Human;
		fl->setPoints(QPoint(175,-75), QPoint(-75,175));
	}

	// Mensaje si el juego esta acabado
	if (result == Human) {
		block = true;
		endGame = true;
		addItem(fl);
		fl->setZValue(1);
		update();
		ganador = Human;
		win++;
		endFinalLine();
		
		return true;
	}
	if (result == Machine) {
		block = true;
		endGame = true;
		addItem(fl); 
		fl->setZValue(2);
		update();
		ganador = Machine;
		lose++;
		endFinalLine();
		
		return true;
	}
	if (result == -2 && !algunaCasillaLibre()) {
		block = true;
		endGame = true;
		ganador = Human+Machine;
		draw++;
		endFinalLine();
		
		return true;
	}
	return false;
}

void GraphicsScene::endFinalLine()
{
	if (ganador == Machine) {
		m_winner->setPlainText("You have lost!");
		m_winner->setPos(-50, -150);
	}
	if (ganador == Human )
	{
		m_winner->setPlainText("You have won!");
		m_winner->setPos(-55, -150);
	}
	if (ganador == Human+Machine) {
		m_winner->setPlainText("Tie Game!");
		m_winner->setPos(-35, -150);
	}
	
		
	if (ganador == Machine || ganador == Human+Machine)
		m_restart->setPlainText("Try again?");
	else
		m_restart->setPlainText("Restart");
}

void GraphicsScene::cleanAll()
{
	int* p = matrix[0];
	qDeleteAll(m_grid.begin(), m_grid.end() );
	for (int i = 0 ; i < All ; ++i, p++)
	{
		m_grid[i] = new Shape(i);
		m_grid[i]->defineShapeImage(Human, userImg );
		m_grid[i]->addData(Shapes, Empty);
		addItem(m_grid[i]);
		*p = Empty;
	}
	if (ganador != Human+Machine)
		removeItem(fl);
	
	m_winner->setPlainText("");
	m_restart->setPlainText("");
	block = false;
	endGame = false;
	if (ganador == Human)
		CPUMove();
}

void GraphicsScene::restartGame()
{
	ganador = Machine; // forced to remove fl
	cleanAll();
}

void GraphicsScene::statistics()
{
	QMessageBox msgBox;
	QString resultados = QString("Wins: \t %1\t\nLost: \t %2 \nDraws: \t %3").arg(win).arg(lose).arg(draw);
	msgBox.setText(resultados);
	msgBox.setStandardButtons(QMessageBox::Ok);
	msgBox.setDefaultButton(QMessageBox::Ok);
	msgBox.exec();
}

void GraphicsScene::changeShape()
{
	QMessageBox messageBox;
	messageBox.setText("What shape do you want?");
	QPushButton* OButton = messageBox.addButton("Circle", QMessageBox::ActionRole);
	OButton->setIcon(QIcon("/usr/share/threeTicTac/o.png"));
	QPushButton* XButton = messageBox.addButton("Cross", QMessageBox::ActionRole);
	XButton->setIcon(QIcon("/usr/share/threeTicTac/x.png"));
	
	int option = messageBox.exec();
	
	if (option == 0)
		userImg = 'o';
	if (option == 1)
		userImg = 'x';
	
	restartGame();
}

#include "graphicsscene.moc"

==> threetictac_0.7-2.tar.gz: threetictac-0.7/src/graphicsscene.cpp <==
/*
    A Qt game based on Tic Tac Toe for Maemo
    Copyright (C) 2010  Victor Blazquez Francisco <victor.blazquez@gmail.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "graphicsscene.h"
#include "shape.h"
#include "machineia.h"
#include "finalline.h"

#include <QGraphicsItem>
#include <QGraphicsSceneMouseEvent>
#include <QPropertyAnimation>
#include <QObject>
#include <QDebug>
#include <QInputDialog>
#include <QMessageBox>
#include <QString>
#include <QPushButton>

GraphicsScene::GraphicsScene(QObject* parent): QGraphicsScene(parent)
{
	QGraphicsPixmapItem* m_background = addPixmap(QPixmap("/usr/share/threeTicTac/bg.png", 0));
	m_background->setZValue(-3);
	m_background->setPos(-350, -180);
	m_background->setData(Shapes , Img);
	
	QGraphicsPixmapItem* m_gridImage = addPixmap(QPixmap("/usr/share/threeTicTac/lines.png", 0));
	m_gridImage->setZValue(-2);
	m_gridImage->setPos(-103,-103);
	m_gridImage->setData(Shapes , Img);

	m_textLevel = new QGraphicsTextItem;
	m_textLevel->setPos(-300,200);
	QFont serifFont("Times", 18, QFont::Bold);
	m_textLevel->setFont(serifFont);
	m_textLevel->setDefaultTextColor(Qt::white);
	m_textLevel->setData(Shapes, "textLevel");
	addItem(m_textLevel);
	updateLevelText();

	m_winner = new QGraphicsTextItem;
	serifFont.setPointSize(24);
	m_winner->setFont(serifFont);
	m_winner->setDefaultTextColor(Qt::white);
	addItem(m_winner);
	
	m_restart = new QGraphicsTextItem;
	m_restart->setPos(250, 180);
	serifFont.setPointSize(24);
	m_restart->setFont(serifFont);
	m_restart->setDefaultTextColor(Qt::green);
	m_restart->setData(Shapes, "restartGame");
	addItem(m_restart);
	
	
	m_grid.resize(All);
	int *p = matrix[0];
	for (int i=0 ; i< All ; ++i, p++) 
	{
		m_grid[i] = new Shape(i);
		m_grid[i]->addData(Shapes, Empty);
		addItem(m_grid[i]);
		*p = Empty;
	}
	fl = new FinalLine;
	block = false;
	endGame = false;
	win = draw = lose = 0;
	players = 1;
}

// void GraphicsScene::askUserName()
// {
// 	QInputDialog id;
// 	userName = id.getText(NULL, "User name","What is your name?");
// }

void GraphicsScene::changeLevel()
{	
	m_machine.setLevel(m_machine.level() + 1);
	updateLevelText();
	restartGame();
}

void GraphicsScene::changeLevel(int level)
{
	m_machine.setLevel(level);
	updateLevelText();
	restartGame();
}

void GraphicsScene::updatePlayerText()
{
	if (movePlayer == 1) m_textLevel->setPlainText("Player 1 moves");
	if (movePlayer == 2) m_textLevel->setPlainText("Player 2 moves");
}

void GraphicsScene::updateLevelText()
{
	QString level_string;
	int machine_level = m_machine.level();
	if (machine_level == 0)
		level_string = "Level: I";
	else
		level_string = "Level: II";
	m_textLevel->setPlainText(level_string);
}

void GraphicsScene::mousePressEvent(QGraphicsSceneMouseEvent* event)
{
	QGraphicsScene::mousePressEvent(event);
	QGraphicsItem* item = itemAt(event->scenePos());

	if (!block && !endGame && players == 1)
	{
		block = true;
		
		if (item->data(Shapes) == Empty) {
			int element = item->data(Positions).toInt();
			
			animOp = new QPropertyAnimation(m_grid[element], "opacity");
			animOp->setStartValue(0);
			animOp->setDuration(400);
			animOp->setEndValue(1);
			animOp->start();	
			
			m_grid[element]->addData(Shapes,Human);
			matrix[element/3][element%3] = Human;
			connect(animOp, SIGNAL(finished()), this, SLOT(endUserAnimation()));
		}
		else
			block = false;
	}
	if (!endGame && players == 2)
	{
		if (item->data(Shapes) == Empty) {
			int element = item->data(Positions).toInt();
			
			animOp = new QPropertyAnimation(m_grid[element], "opacity");
			animOp->setStartValue(0);
			animOp->setDuration(400);
			animOp->setEndValue(1);
			animOp->start();	
		
			if (movePlayer == 1)
			{
				m_grid[element]->addData(Shapes,Human);
				matrix[element/3][element%3] = Human;
				connect(animOp, SIGNAL(finished()), this, SLOT(endUserAnimation()));
			}
			if (movePlayer == 2)
			{
				m_grid[element]->addData(Shapes, Machine);
				matrix[element/3][element%3] = Machine;
				connect(animOp, SIGNAL(finished()), this, SLOT(endUserAnimation()));
			}
		}
	}
	
	if (item->data(Shapes) == "textLevel" && players == 1)
		changeLevel();
	if (item->data(Shapes) == "restartGame")
		cleanAll();
}

bool GraphicsScene::algunaCasillaLibre() 
{
	for (int i=0 ; i< All ; ++i)
	{
		if (m_grid[i]->data(Shapes).toInt() == Empty) 
			return true;
	}
	return false;
}

void GraphicsScene::endUserAnimation()
{
    delete animOp;
	if (players == 1)
	{
		if (!checkFinish())
		{
			block = true;
			CPUMove();
		}
	}
	if (players == 2)
	{
		checkFinish();
		if (movePlayer == 1)
			movePlayer = 2;
		else 
			movePlayer = 1;
		updatePlayerText();
	}
}

void GraphicsScene::CPUMove()
{
	m_machine.updateMatrix(matrix);
	int element = m_machine.bestPosition();
	
	animOp = new QPropertyAnimation(m_grid[element], "opacity");
	animOp->setStartValue(0);
	animOp->setDuration(800);
	animOp->setEndValue(1);
	animOp->start();	

	m_grid[element]->addData(Shapes, Machine);
	matrix[element/3][element%3] = Machine;
	connect(animOp, SIGNAL(finished()), this, SLOT(endMachineAnimation()));
}

void GraphicsScene::endMachineAnimation()
{
	delete animOp;
	checkFinish();
	block = false;
}

bool GraphicsScene::checkFinish() 
{		
	// Machine = maquina  // Human = jugador
	int result = -2;
	/*	0	1	2	*/
	/*	3	4	5	*/
	/*	6	7	8	*/
	/********** GANA MAQUINA ********/
	// Filas
	if (matrix[0][0] == Machine && matrix[0][1] == Machine && matrix[0][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-90,-50), QPoint(190,-50));
	}
	if (matrix[1][0] == Machine && matrix[1][1] == Machine && matrix[1][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-90,50), QPoint(190,50));
	}
	if (matrix[2][0] == Machine && matrix[2][1] == Machine && matrix[2][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-90,150), QPoint(190,150));
	}
	// Columnas
	if (matrix[0][0] == Machine && matrix[1][0] == Machine && matrix[2][0] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-50,-90), QPoint(-50, 190));
	}
	if (matrix[0][1] == Machine && matrix[1][1] == Machine && matrix[2][1] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(50,-90), QPoint(50,190));
	}
	if (matrix[0][2] == Machine && matrix[1][2] == Machine && matrix[2][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(150,-90), QPoint(150,190));
	}
	// Diagonal
	if (matrix[0][0] == Machine && matrix[1][1] == Machine && matrix[2][2] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(-75,-75), QPoint(175,175));
	}
	if (matrix[0][2] == Machine && matrix[1][1] == Machine && matrix[2][0] == Machine) {
		result = Machine;
		fl->setPoints(QPoint(175,-75), QPoint(-75,175));
	}

	/********** GANA JUGADOR ********/
	//Columnas
	if (matrix[0][0] == Human && matrix[0][1] == Human && matrix[0][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-90,-50), QPoint(190,-50));
	}
	if (matrix[1][0] == Human && matrix[1][1] == Human && matrix[1][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-90,50), QPoint(190,50));
	}
	if (matrix[2][0] == Human && matrix[2][1] == Human && matrix[2][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-90,150), QPoint(190,150));
	}
	//Filas
	if (matrix[0][0] == Human && matrix[1][0] == Human && matrix[2][0] == Human) {
		result = Human;
		fl->setPoints(QPoint(-50,-90), QPoint(-50, 190));
	}
	if (matrix[0][1] == Human && matrix[1][1] == Human && matrix[2][1] == Human) {
		result = Human;
		fl->setPoints(QPoint(50,-90), QPoint(50,190));
	}
	if (matrix[0][2] == Human && matrix[1][2] == Human && matrix[2][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(150,-90), QPoint(150,190));
	}
	// Diagonal
	if (matrix[0][0] == Human && matrix[1][1] == Human && matrix[2][2] == Human) {
		result = Human;
		fl->setPoints(QPoint(-75,-75), QPoint(175,175));
	}
	if (matrix[0][2] == Human && matrix[1][1] == Human && matrix[2][0] == Human) {
		result = Human;
		fl->setPoints(QPoint(175,-75), QPoint(-75,175));
	}

	// Mensaje si el juego esta acabado
	if (result == Human) {
		endGame = true;
		addItem(fl);
		fl->setZValue(1);
		update();
		ganador = Human;
		if (players == 1)
			win++;
		endFinalLine();
		
		return true;
	}
	if (result == Machine) {
		endGame = true;
		addItem(fl); 
		fl->setZValue(2);
		update();
		ganador = Machine;
		if (players == 1)
			lose++;
		endFinalLine();
		
		return true;
	}
	if (result == -2 && !algunaCasillaLibre()) {
		endGame = true;
		ganador = Human+Machine;
		if (players == 1)
			draw++;
		endFinalLine();
		
		return true;
	}
	return false;
}

void GraphicsScene::endFinalLine()
{
	if (ganador == Machine) {
		if (players == 1)
		{
			m_winner->setPlainText("You have lost!");
			m_winner->setPos(-50, -150);
		}
		if (players == 2)
		{
			m_winner->setPlainText("Player 2 wins");
			m_winner->setPos(-35, -150);
		}
	}
	if (ganador == Human )
	{
		if (players == 1)
		{
			m_winner->setPlainText("You have won!");
			m_winner->setPos(-55, -150);
		}
		if (players == 2)
		{
			m_winner->setPlainText("Player 1 wins");
			m_winner->setPos(-50, -150);
		}
	}
	if (ganador == Human+Machine) {
		m_winner->setPlainText("Tie Game!");
		m_winner->setPos(-35, -150);
	}
	
		
	if (ganador == Machine || ganador == Human+Machine)
		m_restart->setPlainText("Try again?");
	else
		m_restart->setPlainText("Restart");
}

void GraphicsScene::cleanAll()
{
	int* p = matrix[0];
	qDeleteAll(m_grid.begin(), m_grid.end() );
	for (int i = 0 ; i < All ; ++i, p++)
	{
		m_grid[i] = new Shape(i);
		m_grid[i]->defineShapeImage(Human, userImg );
		m_grid[i]->addData(Shapes, Empty);
		addItem(m_grid[i]);
		*p = Empty;
	}
	if (ganador != Human+Machine)
		removeItem(fl);
	
	m_winner->setPlainText("");
	m_restart->setPlainText("");
	block = false;
	endGame = false;
	
	if (players == 1)
		updateLevelText();
	else
		updatePlayerText();
	
	if (ganador == Machine && players == 1)
	{
		block = true;
		CPUMove();
	}
}

void GraphicsScene::restartGame()
{
	ganador = Machine; // forced to remove fl
	cleanAll();
}

void GraphicsScene::statistics()
{
	QMessageBox msgBox;
	QString resultados = QString("Wins: \t %1\t\nLost: \t %2 \nDraws: \t %3").arg(win).arg(lose).arg(draw);
	msgBox.setText(resultados);
	msgBox.setStandardButtons(QMessageBox::Ok);
	msgBox.setDefaultButton(QMessageBox::Ok);
	msgBox.exec();
}

void GraphicsScene::changeShape()
{
	QMessageBox messageBox;
	if (players == 1)
		messageBox.setText("What shape do you want?");
	else
		messageBox.setText("What shape do you want for player 1?");
	QPushButton* OButton = messageBox.addButton("Circle", QMessageBox::ActionRole);
	OButton->setIcon(QIcon("/usr/share/threeTicTac/o.png"));
	QPushButton* XButton = messageBox.addButton("Cross", QMessageBox::ActionRole);
	XButton->setIcon(QIcon("/usr/share/threeTicTac/x.png"));
	
	int option = messageBox.exec();
	
	if (option == 0)
		userImg = 'o';
	if (option == 1)
		userImg = 'x';
	
	restartGame();
}

void GraphicsScene::twoPlayers()
{
	if (players == 1)
	{
		players = 2;
		updatePlayerText();
	}
	else
	{
		players = 1;
		updateLevelText();
	}
	movePlayer = 1;
	restartGame();
}

int GraphicsScene::numberPlayers()
{
	return players;
}


#include "graphicsscene.moc"
